/* $Id: test_team.cpp 48153 2011-01-01 15:57:50Z mordante $ */
/*
   Copyright (C) 2007 - 2011 by Karol Nowak <grywacz@gmail.com>
   Part of the Battle for Wesnoth Project http://www.wesnoth.org/

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY.

   See the COPYING file for more details.
*/

#define GETTEXT_DOMAIN "wesnoth-test"

#include <boost/test/unit_test.hpp>


BOOST_AUTO_TEST_SUITE( teams )

BOOST_AUTO_TEST_CASE( test_user_team_name )
{
	BOOST_WARN_EQUAL(0,0);
}

/* vim: set ts=4 sw=4: */
BOOST_AUTO_TEST_SUITE_END()
